==> nocc-1.2.tbz: www/nocc/lang/el.php <==
<?php
/*
 * $Header: /cvsroot/nocc/nocc/webmail/lang/el.php,v 1.34 2006/06/23 12:43:31 goddess_skuld Exp $ 
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * Configuration file for the Greek language
 * Translation by Spyros Ioakim <sioakim@ace-hellas.gr>
 */

$charset = 'UTF-8';

// Configuration for the days and months

// What language to use
// see '/usr/share/locale/' for more information
$lang_locale = 'el_GR.UTF-8';

// Text Alignment
// Can be right-to-left (rtl) which is needed for proper Arabic, Hebrew
// Or left-to-right (ltr) which is default for most languages
$lang_dir = 'ltr';

// What format string should we pass to strftime() for messages sent on
// days other than today?
$default_date_format = '%d-%m-%Y'; 

// If the local is not implemented on the host, how we display the date
$no_locale_date_format = '%d-%m-%Y';

// What format string should we pass to strftime() for messages sent
// today?
$default_time_format = '%I:%M %p';


// Here is the configuration for the HTML

$err_user_empty = 'Το πεδίο όνομα λογαριασμού είναι άδειο';
$err_passwd_empty = 'Το πεδίο κωδικός είναι άδειο';


// html message

$alt_delete = 'Διαγραφή επιλεγμένων μηνυμάτων';
$alt_delete_one = 'Διαγραφή μηνύματος';
$alt_new_msg = 'Νέα μηνύματα';
$alt_reply = 'Απάντηση στον αποστολέα';
$alt_reply_all = 'Απάντηση σε όλους';
$alt_forward = 'Προώθηση';
$alt_next = 'Επόμενο μήνυμα';
$alt_prev = 'Προηγούμενο μήνυμα';
$html_on = 'on';  //to translate
$html_theme = 'Θέμα';

// index.php

$html_lang = 'Γλώσσα';
$html_welcome = 'Καλώς ήρθατε στο';
$html_login = 'Ονομα λογαριασμού';
$html_passwd = 'Κωδικός';
$html_submit = 'Login';
$html_help = 'Βοήθεια';
$html_server = 'Διακομιστής';
$html_wrong = 'Το όνομα λογαριασμού ή ο κωδικός είναι λάθος';
$html_retry = 'Επανάληψη';
$html_remember = "Remember settings"; //to translate

// prefs.php

$html_msgperpage = 'Messages per page';  //to translate
$html_preferences = 'Προτιμήσεις';
$html_full_name = 'Ονοματεπώνυμο';
$html_email_address = 'E-mail διεύθυνση';
$html_ccself = 'Αντίγραφο στον ευατό μου';
$html_hide_addresses = 'Απόκρυψη διευθύνσεων';
$html_outlook_quoting = 'Στυλ Outlook παραθέσεις';
$html_reply_to = 'Απάντηση σε';
$html_use_signature = 'Χρησιμοποίηση υπογραφής';
$html_signature = 'Υπογραφή';
$html_reply_leadin = 'Reply Leadin';  //to translate
$html_prefs_updated = 'Οι Προτιμήσεις σας ανανεώθηκαν';
$html_manage_folders_link = 'Manage IMAP Folders';  //to translate
$html_manage_filters_link = 'Manage Email Filters';  //to translate
$html_use_graphical_smilies = 'Use graphical smilies'; //to translate
$html_sent_folder = 'Copy sent mails into a dedicated folder'; //to translate

// folders.php
$html_folders_create_failed = 'Folder could not be created!';  //to translate
$html_folders_sub_failed = 'Could not subscribed to folder!';  //to translate
$html_folders_unsub_failed = 'Could not unsubscribed from folder!';  //to translate
$html_folders_rename_failed = 'Folder could not be renamed!';  //to translate
$html_folders_updated = 'Folders updated';  //to translate
$html_folder_subscribe = 'Subscribe to';  //to translate
$html_folder_rename = 'Rename';  //to translate
$html_folder_create = 'Create new folder called';  //to translate
$html_folder_remove = 'Unsubscribe from';  //to translate
$html_folder_delete = 'Delete';  //to translate

// filters.php
$html_filter_remove = 'Delete';  //to translate
$html_filter_body = 'Message Body';  //to translate
$html_filter_subject = 'Message Subject';  //to translate
$html_filter_to = 'To Field';  //to translate
$html_filter_cc = 'Cc Field';  //to translate
$html_filter_from = 'From Field';  //to translate
$html_filter_change_tip = 'To change a filter simply overwrite it.';  //to translate
$html_reapply_filters = 'Reapply all filters';  //to translate
$html_filter_contains = 'contains';  //to translate
$html_filter_name = 'Filter Name';  //to translate
$html_filter_action = 'Filter Action';  //to translate
$html_filter_moveto = 'Move to';  //to translate

// Other pages
$html_select_one = '--Select One--';  //to translate
$html_and = 'And';  //to translate
$html_new_msg_in = 'New messages in';  //to translate
$html_or = 'or';  //to translate
$html_move = 'Move';  //to translate
$html_copy = 'Copy';  //to translate
$html_messages_to = 'selected messages to';  //to translate
$html_gotopage = 'Go to Page';  //to translate
$html_gotofolder = 'Go to Folder';  //to translate
$html_other_folders = 'Folder List';  //to translate
$html_page = 'Page';  //to translate
$html_of = 'of';  //to translate
$html_to = 'to';  //to translate
$html_view_header = 'Προβολή λεπτομερειών';
$html_remove_header = 'Απόκρυψη λεπτομερειών';
$html_inbox = 'Inbox';
$html_new_msg = 'Σύνθεση';
$html_reply = 'Απάντηση';
$html_reply_short = 'Re';
$html_reply_all = 'Απάντηση σε όλους';
$html_forward = 'Προώθηση';
$html_forward_short = 'Fw';
$html_forward_info = 'The forwarded message will be send as an attachment to this one.'; //to translate
$html_delete = 'Διαγραφή';
$html_new = 'Νέο';
$html_mark = 'Διαγραφή';
$html_att = 'Συνημμένο';
$html_atts = 'Συνημμένα';
$html_att_unknown = '[άγνωστο]';
$html_attach = 'Επισύναψη';
$html_attach_forget = 'Πρέπει να συννάψετε το αρχείο πρίν στείλετε το μήνυμα !';
$html_attach_delete = 'Διαγραφή μαρκαρισμένων συνημμένων';
$html_attach_none = 'You must select a file to attach!';  //to translate
$html_sort_by = 'Sort by';  //to translate
$html_from = 'Από';
$html_subject = 'Θέμα';
$html_date = 'Ημ/νία';
$html_sent = 'Αποστολή';
$html_wrote = 'wrote';
$html_size = 'Μέγεθος';
$html_totalsize = 'Συνολικό μέγεθος';
$html_kb = 'Kb';
$html_bytes = 'bytes';
$html_filename = 'Ονομα αρχείου';
$html_to = 'Πρός';
$html_cc = 'Αντίγραφο προς';
$html_bcc = 'Κρυφό Αντίγραφο προς';
$html_nosubject = 'Χωρίς Θέμα';
$html_send = 'Αποστολή';
$html_cancel = 'Ακυρο';
$html_no_mail = 'Δεν υπάρχουν μηνύματα.';
$html_logout = 'Εξοδος';
$html_msg = 'Μήνυμα';
$html_msgs = 'Μηνύματα';
$html_configuration = 'Αυτός ο διακομιστής δεν έχει οριστεί σωστά !';
$html_priority = 'Προταιραιότητα';
$html_low = 'Χαμηλή';
$html_normal = 'Κανονική';
$html_high = 'Υψηλή';
$html_receipt = 'Request a return receipt';  //to translate
$html_select = 'Διαλέξτε';
$html_select_all = 'Invert Selection';  //to translate
$html_loading_image = 'Φορτώνω την εικόνα';
$html_send_confirmed = 'Το μήνυμα σας θα αποσταλεί.';
$html_no_sendaction = 'Δεν επιλέχθηκε εντολή. Δοκιμάστε να ενεργοποιήσετε τηνJavaScript.';
$html_error_occurred = 'Ενα σφάλμα συνέβη';
$html_prefs_file_error = 'Δεν μπορώ να γράψω στο αρχείο προτιμήσεων.';
$html_wrap = 'Wrap outgoing messages to :';  //to translate
$html_wrap_none = 'None'; //to translate
$html_usenet_separator = 'Usenet separator ("-- \n") Before signature';  //to translate
$html_mark_as = 'Mark as'; //to translate
$html_read = 'read'; //to translate
$html_unread = 'unread'; //to translate
$html_mail_sent = 'Message successfully sent'; // to translate
$html_encoding = 'Character encoding'; // to translate

// Contacts manager
$html_add = 'Add';  //to translate
$html_contacts = 'Contacts';  //to translate
$html_modify = 'Modify';  //to translate
$html_back = 'Back';  //to translate
$html_contact_add = 'Add new contact';  //to translate
$html_contact_mod = 'Modify a contact';  //to translate
$html_contact_first = 'First name';  //to translate
$html_contact_last = 'Last Name';  //to translate
$html_contact_nick = 'Nick';  //to translate
$html_contact_mail = 'Mail';  //to translate
$html_contact_list = 'Contact list of ';  //to translate
$html_contact_del = 'from the contact list';  //to translate

$html_contact_err1 = 'Maximal number of contact is ';  //to translate
$html_contact_err2 = 'You can\'t add a new contact';  //to translate
$html_contact_err3 = 'You don\'t have access rights to contact list'; //to translate
$html_del_msg = 'Delete selected messages ?';  //to translate
$html_down_mail = 'Download';  //to translate

$original_msg = '-- Πρωτότυπο Μήνυμα --';
$to_empty = 'Το πεδίο \'Πρός\' δεν πρέπει να είναι άδειο !';

// Images warning
$html_images_warning = 'For your security, remote pictures are not displayed.'; // to translate
$html_images_display = 'Display pictures'; // to translate

// SMTP problems (class_smtp.php)
$html_smtp_error_no_conn = 'Δεν μπορώ να ανοίξω σύνδεση';
$html_smtp_error_unexpected = 'Αγνωστη απάντηση:';

// IMAP messages (class_local.php)
$lang_could_not_connect = 'Could not connect to server';  //to translate
$lang_invalid_msg_num = 'Bad Message Number';  //to translate

$html_file_upload_attack = 'Possible file upload attack';  //to translate
$html_invalid_email_address = 'Invalid e-mail address';  //to translate
$html_invalid_msg_per_page = 'Invalid number of messages per page';  //to translate
$html_invalid_wrap_msg = 'Invalid message wrap width';  //to translate
$html_seperate_msg_win = 'Messages in separate window';  //to translate

// Exceptions
$html_err_file_contacts = 'Unable to open contacts file for writing.'; //to translate
?>

==> nocc-1.4.tbz: www/nocc/lang/el.php <==
<?php
/*
 * $Header: /cvsroot/nocc/nocc/webmail/lang/el.php,v 1.44 2006/10/20 12:20:00 goddess_skuld Exp $ 
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * Configuration file for the Greek language
 * Translation by Spyros Ioakim <sioakim@ace-hellas.gr>
 */

$charset = 'UTF-8';

// Configuration for the days and months

// What language to use
// see '/usr/share/locale/' for more information
$lang_locale = 'el_GR.UTF-8';

// Text Alignment
// Can be right-to-left (rtl) which is needed for proper Arabic, Hebrew
// Or left-to-right (ltr) which is default for most languages
$lang_dir = 'ltr';

// What format string should we pass to strftime() for messages sent on
// days other than today?
$default_date_format = '%d-%m-%Y'; 

// If the local is not implemented on the host, how we display the date
$no_locale_date_format = '%d-%m-%Y';

// What format string should we pass to strftime() for messages sent
// today?
$default_time_format = '%I:%M %p';


// Here is the configuration for the HTML

$err_user_empty = 'Το πεδίο όνομα λογαριασμού είναι άδειο';
$err_passwd_empty = 'Το πεδίο κωδικός είναι άδειο';


// html message

$alt_delete = 'Διαγραφή επιλεγμένων μηνυμάτων';
$alt_delete_one = 'Διαγραφή μηνύματος';
$alt_new_msg = 'Νέα μηνύματα';
$alt_reply = 'Απάντηση στον αποστολέα';
$alt_reply_all = 'Απάντηση σε όλους';
$alt_forward = 'Προώθηση';
$alt_next = 'Next'; //to translate
$alt_prev = 'Previous'; //to translate
$title_next_page = 'Next page'; //to translate
$title_prev_page = 'Previous page'; //to translate
$title_next_msg = 'Επόμενο μήνυμα';
$title_prev_msg = 'Προηγούμενο μήνυμα';
$html_on = 'on';  //to translate
$html_theme = 'Θέμα';

// index.php

$html_lang = 'Γλώσσα';
$html_welcome = 'Καλώς ήρθατε στο';
$html_login = 'Ονομα λογαριασμού';
$html_passwd = 'Κωδικός';
$html_submit = 'Login'; //to translate
$html_help = 'Βοήθεια';
$html_server = 'Διακομιστής';
$html_wrong = 'Το όνομα λογαριασμού ή ο κωδικός είναι λάθος';
$html_retry = 'Επανάληψη';
$html_remember = "Remember settings"; //to translate

// prefs.php

$html_msgperpage = 'Messages per page';  //to translate
$html_preferences = 'Προτιμήσεις';
$html_full_name = 'Ονοματεπώνυμο';
$html_email_address = 'E-mail διεύθυνση';
$html_ccself = 'Αντίγραφο στον ευατό μου';
$html_hide_addresses = 'Απόκρυψη διευθύνσεων';
$html_outlook_quoting = 'Στυλ Outlook παραθέσεις';
$html_reply_to = 'Απάντηση σε';
$html_use_signature = 'Χρησιμοποίηση υπογραφής';
$html_signature = 'Υπογραφή';
$html_reply_leadin = 'Reply Leadin';  //to translate
$html_prefs_updated = 'Οι Προτιμήσεις σας ανανεώθηκαν';
$html_manage_folders_link = 'Manage IMAP Folders';  //to translate
$html_manage_filters_link = 'Manage Email Filters';  //to translate
$html_use_graphical_smilies = 'Use graphical smilies'; //to translate
$html_sent_folder = 'Copy sent mails into a dedicated folder'; //to translate
$html_colored_quotes = 'Colored quotes'; //to translate
$html_display_struct = 'Display structured text'; //to translate
$html_send_html_mail = 'Send mail in HTML format'; //to translate

// folders.php
$html_folders_create_failed = 'Folder could not be created!';  //to translate
$html_folders_sub_failed = 'Could not subscribed to folder!';  //to translate
$html_folders_unsub_failed = 'Could not unsubscribed from folder!';  //to translate
$html_folders_rename_failed = 'Folder could not be renamed!';  //to translate
$html_folders_updated = 'Folders updated';  //to translate
$html_folder_subscribe = 'Subscribe to';  //to translate
$html_folder_rename = 'Rename';  //to translate
$html_folder_create = 'Create new folder called';  //to translate
$html_folder_remove = 'Unsubscribe from';  //to translate
$html_folder_delete = 'Delete';  //to translate
$html_folder_to = 'to'; //to translate

// filters.php
$html_filter_remove = 'Delete';  //to translate
$html_filter_body = 'Message Body';  //to translate
$html_filter_subject = 'Message Subject';  //to translate
$html_filter_to = 'To Field';  //to translate
$html_filter_cc = 'Cc Field';  //to translate
$html_filter_from = 'From Field';  //to translate
$html_filter_change_tip = 'To change a filter simply overwrite it.';  //to translate
$html_reapply_filters = 'Reapply all filters';  //to translate
$html_filter_contains = 'contains';  //to translate
$html_filter_name = 'Filter Name';  //to translate
$html_filter_action = 'Filter Action';  //to translate
$html_filter_moveto = 'Move to';  //to translate

// Other pages
$html_select_one = '--Select One--';  //to translate
$html_and = 'And';  //to translate
$html_new_msg_in = 'New messages in';  //to translate
$html_or = 'or';  //to translate
$html_move = 'Move';  //to translate
$html_copy = 'Copy';  //to translate
$html_messages_to = 'selected messages to';  //to translate
$html_gotopage = 'Go to Page';  //to translate
$html_gotofolder = 'Go to Folder';  //to translate
$html_other_folders = 'Folder List';  //to translate
$html_page = 'Page';  //to translate
$html_of = 'of';  //to translate
$html_view_header = 'Προβολή λεπτομερειών';
$html_remove_header = 'Απόκρυψη λεπτομερειών';
$html_inbox = 'Inbox'; //to translate
$html_new_msg = 'Σύνθεση';
$html_reply = 'Απάντηση';
$html_reply_short = 'Re'; //to translate
$html_reply_all = 'Απάντηση σε όλους';
$html_forward = 'Προώθηση';
$html_forward_short = 'Fw'; //to translate
$html_forward_info = 'The forwarded message will be send as an attachment to this one.'; //to translate
$html_delete = 'Διαγραφή';
$html_new = 'Νέο';
$html_mark = 'Διαγραφή';
$html_att = 'Συνημμένο';
$html_atts = 'Συνημμένα';
$html_att_unknown = '[άγνωστο]';
$html_attach = 'Επισύναψη';
$html_attach_forget = 'Πρέπει να συννάψετε το αρχείο πρίν στείλετε το μήνυμα !';
$html_attach_delete = 'Διαγραφή μαρκαρισμένων συνημμένων';
$html_attach_none = 'You must select a file to attach!';  //to translate
$html_sort_by = 'Sort by';  //to translate
$html_sort = 'Sort'; //to translate
$html_from = 'Από';
$html_subject = 'Θέμα';
$html_date = 'Ημ/νία';
$html_sent = 'Αποστολή';
$html_wrote = 'wrote'; //to translate
$html_size = 'Μέγεθος';
$html_totalsize = 'Συνολικό μέγεθος';
$html_kb = 'kB'; //to translate
$html_bytes = 'bytes'; //to translate
$html_filename = 'Ονομα αρχείου';
$html_to = 'Πρός';
$html_cc = 'Αντίγραφο προς';
$html_bcc = 'Κρυφό Αντίγραφο προς';
$html_nosubject = 'Χωρίς Θέμα';
$html_send = 'Αποστολή';
$html_cancel = 'Ακυρο';
$html_no_mail = 'Δεν υπάρχουν μηνύματα.';
$html_logout = 'Εξοδος';
$html_msg = 'Μήνυμα';
$html_msgs = 'Μηνύματα';
$html_configuration = 'Αυτός ο διακομιστής δεν έχει οριστεί σωστά !';
$html_priority = 'Προταιραιότητα';
$html_low = 'Χαμηλή';
$html_normal = 'Κανονική';
$html_high = 'Υψηλή';
$html_receipt = 'Request a return receipt';  //to translate
$html_select = 'Διαλέξτε';
$html_select_all = 'Invert Selection';  //to translate
$html_loading_image = 'Φορτώνω την εικόνα';
$html_send_confirmed = 'Το μήνυμα σας θα αποσταλεί.';
$html_no_sendaction = 'Δεν επιλέχθηκε εντολή. Δοκιμάστε να ενεργοποιήσετε τηνJavaScript.';
$html_error_occurred = 'Ενα σφάλμα συνέβη';
$html_prefs_file_error = 'Δεν μπορώ να γράψω στο αρχείο προτιμήσεων.';
$html_wrap = 'Wrap outgoing messages to :';  //to translate
$html_wrap_none = 'None'; //to translate
$html_usenet_separator = 'Usenet separator ("-- \n") Before signature';  //to translate
$html_mark_as = 'Mark as'; //to translate
$html_read = 'read'; //to translate
$html_unread = 'unread'; //to translate
$html_encoding = 'Character encoding'; // to translate

// Contacts manager
$html_add = 'Add';  //to translate
$html_contacts = 'Contacts';  //to translate
$html_modify = 'Modify';  //to translate
$html_back = 'Back';  //to translate
$html_contact_add = 'Add new contact';  //to translate
$html_contact_mod = 'Modify a contact';  //to translate
$html_contact_first = 'First name';  //to translate
$html_contact_last = 'Last Name';  //to translate
$html_contact_nick = 'Nick';  //to translate
$html_contact_mail = 'Mail';  //to translate
$html_contact_list = 'Contact list of ';  //to translate
$html_contact_del = 'from the contact list';  //to translate

$html_contact_err1 = 'Maximal number of contact is ';  //to translate
$html_contact_err2 = 'You can\'t add a new contact';  //to translate
$html_contact_err3 = 'You don\'t have access rights to contact list'; //to translate
$html_del_msg = 'Delete selected messages ?';  //to translate
$html_down_mail = 'Download';  //to translate

$original_msg = '-- Πρωτότυπο Μήνυμα --';
$to_empty = 'Το πεδίο \'Πρός\' δεν πρέπει να είναι άδειο !';

// Images warning
$html_images_warning = 'For your security, remote pictures are not displayed.'; // to translate
$html_images_display = 'Display pictures'; // to translate

// SMTP problems (class_smtp.php)
$html_smtp_error_no_conn = 'Δεν μπορώ να ανοίξω σύνδεση';
$html_smtp_error_unexpected = 'Αγνωστη απάντηση:';

// IMAP messages (class_local.php)
$lang_could_not_connect = 'Could not connect to server';  //to translate
$lang_invalid_msg_num = 'Bad Message Number';  //to translate

$html_file_upload_attack = 'Possible file upload attack';  //to translate
$html_invalid_email_address = 'Invalid e-mail address';  //to translate
$html_invalid_msg_per_page = 'Invalid number of messages per page';  //to translate
$html_invalid_wrap_msg = 'Invalid message wrap width';  //to translate
$html_seperate_msg_win = 'Messages in separate window';  //to translate

// Exceptions
$html_err_file_contacts = 'Unable to open contacts file for writing.'; //to translate
$html_session_file_error = 'Unable to open session file for writing.';  //to translate
$html_login_not_allowed = 'This login is not allowed for connexion.'; //to translate
?>
